#!/bin/sh
echo 'name: semigroupoids
version: 3.0.2
id: semigroupoids-3.0.2-1ab2a6bd02a051ca9ce83fb386006a96

license: BSD3
copyright: Copyright (C) 2011 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/semigroupoids
package-url:
synopsis: Haskell 98 semigroupoids: Category sans id
description: Provides a wide array of semigroupoids and operations for working with semigroupds.
             .
             A Semigroupoid is a Category without the requirement of identity arrows for every object in the category.
             .
             When working with comonads you often have the @\<*\>@ portion of an @Applicative@, but
             not the @pure@. This was captured in Uustalu and Vene'\''s \"Essence of Dataflow Programming\"
             in the form of the @ComonadZip@ class in the days before @Applicative@. Apply provides a weaker invariant, but for the comonads used for data flow programming (found in the streams package), this invariant is preserved. Applicative function composition forms a semigroupoid.
             .
             Similarly many structures are nearly a comonad, but not quite, for instance lists provide a reasonable '\''extend'\'' operation in the form of '\''tails'\'', but do not always contain a value.
             .
             .
             Ideally the following relationships would hold:
             .
             > Traversable <---- Foldable <--- Functor ------> Alt ---------> Plus           Semigroupoid
             >      |               |            |                              |                  |
             >      v               v            v                              v                  v
             > Traversable1 <--- Foldable1     Apply --------> Applicative -> Alternative      Category
             >                                   |               |              |                  |
             >                                   v               v              v                  v
             >                                 Bind ---------> Monad -------> MonadPlus          Arrow
             >
             .
             Apply, Bind, and Extend (not shown) give rise the Static, Kleisli and Cokleisli semigroupoids respectively.
             .
             This lets us remove many of the restrictions from various monad transformers
             as in many cases the binding operation or @\<*\>@ operation does not require them.
             .
             Finally, to work with these weaker structures it is beneficial to have containers
             that can provide stronger guarantees about their contents, so versions of '\''Traversable'\''
             and '\''Foldable'\'' that can be folded with just a '\''Semigroup'\'' are added.
category: Control, Comonads
author: Edward A. Kmett
exposed: True
exposed-modules: Data.Functor.Alt Data.Functor.Apply
                 Data.Functor.Bind Data.Functor.Bind.Trans Data.Functor.Plus
                 Data.Functor.Extend Data.Semigroup.Foldable
                 Data.Semigroup.Traversable Data.Semigroupoid Data.Semigroupoid.Dual
                 Data.Semigroupoid.Static Data.Traversable.Instances
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.2/cabal/semigroupoids-3.0.2
library-dirs: /usr/local/lib/ghc-7.4.2/cabal/semigroupoids-3.0.2
              /usr/local/lib
hs-libraries: HSsemigroupoids-3.0.2
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.5.1.0-12fddc14a7babb909dd3843e453b5660
         comonad-3.0.2-b0ceee3eca078a4979462cf2e86c7b95
         containers-0.4.2.1-efa59805336a77490296ae3897cecb87
         contravariant-0.4-88891eca02b1bda6d03085d1b1009c6d
         semigroups-0.9-7e502949bc7c9e3e2d6f68db86ac326f
         transformers-0.3.0.0-2889ebed7e61112cda7ded5e4c153bcf
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.2/cabal/semigroupoids-3.0.2/html/semigroupoids.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.2/cabal/semigroupoids-3.0.2/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
